% at_DefineYbus.m
% This script defines the bus admittance matrices for pre-fault and faulted
% conditions. It is assumed that post-fault network is the same as
% pre-fault one. Also, it adds constant impedance loads to the matrix.
%
% Needs: 
%             Ybus: Bus admittance matrix of the original system
%             nBus,
%            nLoad,
%             nGen: Number of respective type buses
%          V_busm0: Voltage magnitudes at steady-state
%       P_d0, Q_d0: Load powers at steady-state
%       K_pz, K_qz: linear portion of the load for active and reactive
%                   components
%
% Defines:
%           Y_bus0,
%           Y_busf: Bus admittance matrices for pre-fault and during-fault
%                   conditions
%          Z_gbus0,
%          Z_gbusf: Auxulliary matrices for interfacing loads to the network
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 by Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249


% Start from Ybus from Power Flow
Y_bus0 = Ybus;
clear Ybus

% Convert linear part of loads to constant impedance and update pre-fault Ybus
for i=1:nBus
    Y_bus0(i, i) = Y_bus0(i, i) + (K_pz(i)*P_d0(i) - j*K_qz(i)*Q_d0(i))/V_busm0(i)^2;
end

% Simulate a three-phase fault at bus 5
Y_busf = Y_bus0; Y_busf(5, 5) = 1e6;

% Define aux. matrices, refer to the report for more information
Yg_matrix = [zeros(nLoad, nLoad), zeros(nLoad, nGen)
             zeros(nGen , nLoad), diag(y_gen)
         ];

Z_gbus0 = inv(Y_bus0 + Yg_matrix);
Z_gbusf = inv(Y_busf + Yg_matrix);