% at_OutputGraphs.m
% This script draws graphs of bus voltages, generators internal delta
% angle, and q-axis angle w.r.t. to R-axis. Other graphs can be also easily
% produced.
%
% Needs: 
%             Time: Time instances of simulation
%              Sol: Values of states at different time instances
%      allVoltages: Bus votlages
%
% Defines:
%          NOTHING
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 by Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249

% Define generator indices for legend (My fav part of this code!)
bn = num2str(genBus);
bn(:, 3) = '_';
bn(:, 4) = bn(:, 2);
bn(:, 2) = bn(:, 1);
bn(:, 1) = '_';

vn = num2str((1:nBus)');
vn(:, 3) = '_';
vn(:, 4) = vn(:, 2);
vn(:, 2) = vn(:, 1);
vn(:, 1) = '_';


% Plot the angle between q- and R-axes
disp(sprintf('1. Delta angle of generators vs. time'));
figure
plot(Time, Sol(1*nGen + (1:4), 1:end-1)*180/pi, '-');
axis([0 max(Time) -20 180])
xlabel('t (s)'); ylabel('\delta (deg)');
legend(strcat('\delta', bn))

% Plot DW
disp(sprintf('2. Speed deviation of generators vs. time'));
figure
plot(Time, Sol(0*nGen + (1:4), 1:end-1)*w_0, '-');
xlabel('t (s)'); ylabel('\Delta\omega (rad/s)');
legend(strcat('\Delta\omega', bn))

% Plot psi_fd
disp(sprintf('3. Field circuit flux of generators vs. time'));
figure
plot(Time, Sol(2*nGen + (1:4), 1:end-1), '-');
xlabel('t (s)'); ylabel('\psi_f_d (pu)');
legend(strcat('\psi_f_d', bn))

% Plot bus voltages
disp(sprintf('4. Bus voltages vs. time'));
figure
plot(Time, abs(allVoltages(:, 1:end-1)))
xlabel('t (s)'); ylabel('V_t (pu)');
legend(strcat('V_t', vn))

% Plot internal delta angle
disp(sprintf('5. Internal delta angles vs. time'));
figure
plot(Time, [angle(exp(j* (Sol(1*nGen + (1:4), 1:end-1) - angle(allVoltages(9:12, 1:end-1))) ))] * 180/pi, '-');
axis([0 max(Time) -20 180])
xlabel('t (s)'); ylabel('\delta _i (deg)');
legend(strcat('\delta_i', bn))
