% at_PowerFlowData.m
% This script stores needed power flow data such as bus voltages and
% magnitudes, generators' active and reactive power, loads power, the
% network Ybus, and number of buses for later use in transient stability
% simulation and clears others.
%
% Needs:        Vm, 
%               Va: Bus voltage
%           CalcPg,
%           CalcQg: Generators' power
%     buOriginalPd,
%     buOriginalQd: Load's power
%          baseMVA: Base MVA for the system
%          geMBase: Base MVA for individual generators
%            slack,
%               pv,
%               pq: Indices of respective buses
%
% Defines:   V_bus: Phasor of bus voltages at steady-state
%          V_busm0: Magnitude of bus voltages at steady-state
%              P_g: pu (system base) generated active power by each bus at steady-state 
%              Q_g: pu (system base) generated reactive power by each bus at steady-state
%          geMBase: MVA base of each generator
%           genBus: Indices of generator buses
%          LoadBus: Indices of load buses
%            nLoad: Number of load buses
%             nGen: Number of generator buses
%             nBus: Total number of buses
%             P_d0: Load demand active power at steady-state
%             Q_d0: Load demand reactive power at steady-state
%             Ybus: Network "raw" Ybus (without linear buses)
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 by Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249

% Define variables needed for a_tInitStates
V_bus = Vm .* exp(j*Va);
V_busm0 = Vm;

P_g = calcPg/baseMVA; 
Q_g = calcQg/baseMVA;
P_g(1:8) = 0; Q_g(1:8)=0;

% Define variables needed for a_tDyrRead
geMBase = geMBase';
genBus = [slack; pv];
loadBus = pq;
nLoad = nBus - nGen;

% Define variables needed for a_tReadLoadData
P_d0 = buOriginalPd / baseMVA;
Q_d0 = buOriginalQd / baseMVA;

% Clear unused variables
save AMStabilityVars0x V_bus P_g Q_g geMBase baseMVA nGen genBus loadBus nLoad nBus Ybus P_d0 Q_d0 V_busm0
clear all
load AMStabilityVars0x